@@ -408,6 +408,9 @@ class KwargsDictDialogPage(BaseBox):
 
         """
 
+        # Hide the page
+        self.hide()
+
         # Make empty dict containing all current valid entries
         cur_entry_dict = sdict()
 
@@ -459,6 +462,9 @@ class KwargsDictDialogPage(BaseBox):
             set_box_value(self.kwargs_grid.itemAtPosition(row, 2).widget(),
                           field_value)
 
+        # Show the page
+        self.show()
+
     # This function creates an editable entry
     @QC.Slot()
     @e13.docstring_substitute(qt_slot=qt_slot_doc)
