@@ -21,8 +21,7 @@ from tempfile import mkstemp
 from textwrap import dedent
 
 # Package imports
-from e13tools import InputError, compare_versions
-from e13tools.utils import raise_error, raise_warning
+import e13tools as e13
 import h5py
 from mpi4pyd import MPI
 import numpy as np
@@ -34,9 +33,9 @@ from prism.__version__ import __version__, compat_version
 # All declaration
 __all__ = ['CFilter', 'FeatureWarning', 'PRISM_Logger', 'RFilter',
            'RequestError', 'RequestWarning', 'check_compatibility',
-           'check_vals', 'get_PRISM_File', 'get_formatter', 'get_handler',
-           'get_info', 'getCLogger', 'getLogger', 'getRLogger', 'move_logger',
-           'np_array', 'set_base_logger']
+           'check_vals', 'get_bibtex', 'get_PRISM_File', 'get_formatter',
+           'get_handler', 'get_info', 'getCLogger', 'getLogger', 'getRLogger',
+           'move_logger', 'np_array', 'set_base_logger']
 
 # Determine MPI size and ranks
 size = MPI.COMM_WORLD.Get_size()
@@ -171,30 +170,31 @@ def check_compatibility(emul_version):
     logger = getCLogger('COMP_CHECK')
     logger.info("Performing version compatibility check.")
 
-    # Loop over all compatibility versions
-    for version in compat_version:
-        # If a compat_version is the same or newer than the emul_version
-        # then it is incompatible
-        if compare_versions(version, emul_version):
-            err_msg = ("The provided emulator is incompatible with the current"
-                       " version of PRISM (v%s). The last compatible version "
-                       "is v%s." % (__version__, version))
-            raise_error(err_msg, RequestError, logger)
-
     # Check if emul_version is 1.0.x and raise warning if so
-    if not compare_versions(emul_version, '1.1.0'):
+    if not e13.compare_versions(emul_version, '1.1.0'):
         warn_msg = ("The provided emulator was constructed with an "
                     "unmaintained version of PRISM (v%s). Compatibility with "
                     "the current version of PRISM cannot be guaranteed."
                     % (emul_version))
-        raise_warning(warn_msg, RequestWarning, logger, 2)
+        e13.raise_warning(warn_msg, RequestWarning, logger, 2)
+        return
+
+    # Loop over all compatibility versions
+    for version in compat_version:
+        # If a compat_version is the same or newer than the emul_version
+        # then it is incompatible
+        if e13.compare_versions(version, emul_version):
+            err_msg = ("The provided emulator is incompatible with the current"
+                       " version of PRISM (v%s). The last compatible version "
+                       "is v%s." % (__version__, version))
+            e13.raise_error(err_msg, RequestError, logger)
 
     # Check if emul_version is not newer than prism_version
-    if not compare_versions(__version__, emul_version):
+    if not e13.compare_versions(__version__, emul_version):
         err_msg = ("The provided emulator was constructed with a version later"
                    " than the current version of PRISM (v%s). Use v%s or later"
                    " to use this emulator." % (__version__, emul_version))
-        raise_error(err_msg, RequestError, logger)
+        e13.raise_error(err_msg, RequestError, logger)
     else:
         logger.info("Version compatibility check was successful.")
 
@@ -210,20 +210,21 @@ def check_vals(values, name, *args):
 
     Parameters
     ----------
-    values : array_like of {int, float, complex, str, bool}
+    values : array_like of {bool; complex; float; int; str}
         The values to be checked against all given criteria in `args`. It must
         be possible to convert `values` to a :obj:`~numpy.ndarray` object.
     name : str
         The name of the input argument, which is used in the error message if
         a criterion is not met.
-    args : tuple of {'bool', 'complex', 'float', 'int', 'neg', 'nneg', \
-        'normal', 'npos', 'nzero', 'pos', 'str'}
+    args : positional arguments in {'bool'; 'complex'; 'float'; 'int'; 'neg'; \
+                                    'nneg'; 'normal'; 'npos'; 'nzero'; 'pos'; \
+                                    'str'}
         Sequence of strings determining the criteria that `values` must meet.
         If `args` is empty, it is checked if `values` are finite.
 
     Returns
     -------
-    return_values : array_like of {int, float, complex, str}
+    return_values : array_like of {complex; float; int; str}
         If `args` contained 'bool', returns 0s or 1s. Else, returns `values`.
 
     Notes
@@ -246,34 +247,34 @@ def check_vals(values, name, *args):
         arr_type = 'list'
     elif isinstance(values, np.ndarray):
         arr_type = 'ndarray'
-    elif np.isscalar(values):
+    elif np.isscalar(values) or values is None:
         arr_type = 'scalar'
     else:
         err_msg = "Input argument %r is not array_like!" % (name)
-        raise_error(err_msg, InputError, logger)
+        e13.raise_error(err_msg, e13.InputError, logger)
 
     # Convert values to a NumPy array
     try:
         values = np.asanyarray(values)
-    except Exception as error:
+    except Exception as error:      # pragma: no cover
         err_msg = ("Input argument %r cannot be converted to a NumPy array! "
                    "(%s)" % (name, error))
-        raise_error(err_msg, InputError, logger)
+        e13.raise_error(err_msg, e13.InputError, logger)
     else:
-        # Since NumPy v1.16.0, sequenced lists can be converted to NumPy arrays
+        # Since NumPy v1.16.0, anything can be converted to NumPy arrays
         # So, check if the dtype is not np.object_
         if issubclass(values.dtype.type, np.object_):
-            err_msg = ("Input argument %r cannot be a sequenced container!"
-                       % (name))
-            raise_error(err_msg, InputError, logger)
+            err_msg = ("Input argument %r cannot be converted to a NumPy "
+                       "dtype!" % (name))
+            e13.raise_error(err_msg, TypeError, logger)
 
     # Check if values is not empty and raise error if so
     if not values.size:
         err_msg = "Input argument %r is empty!" % (name)
-        raise_error(err_msg, InputError, logger)
+        e13.raise_error(err_msg, e13.InputError, logger)
 
     # Loop over all criteria
-    while len(args):
+    while args:
         # Check for bool
         if 'bool' in args:
             # Convert values to str
@@ -294,7 +295,7 @@ def check_vals(values, name, *args):
                 index = np.unravel_index(np.argmin(check_list), values.shape)
                 err_msg = ("Input argument '%s%s' is not of type 'bool'!"
                            % (name, list(index) if values.ndim != 0 else ''))
-                raise_error(err_msg, TypeError, logger)
+                e13.raise_error(err_msg, TypeError, logger)
             else:
                 # If so, convert values to integers and break the loop
                 values = np.asanyarray(values, dtype=int)
@@ -307,7 +308,7 @@ def check_vals(values, name, *args):
                 break
             else:
                 err_msg = "Input argument %r is not of type 'str'!" % (name)
-                raise_error(err_msg, TypeError, logger)
+                e13.raise_error(err_msg, TypeError, logger)
 
         # Check for complex
         elif 'complex' in args:
@@ -321,7 +322,7 @@ def check_vals(values, name, *args):
             else:
                 err_msg = ("Input argument %r is not of type 'complex'!"
                            % (name))
-                raise_error(err_msg, TypeError, logger)
+                e13.raise_error(err_msg, TypeError, logger)
 
         # Check for float
         elif 'float' in args:
@@ -333,7 +334,7 @@ def check_vals(values, name, *args):
                 continue
             else:
                 err_msg = "Input argument %r is not of type 'float'!" % (name)
-                raise_error(err_msg, TypeError, logger)
+                e13.raise_error(err_msg, TypeError, logger)
 
         # Check for integer
         elif 'int' in args:
@@ -344,7 +345,7 @@ def check_vals(values, name, *args):
                 continue
             else:
                 err_msg = "Input argument %r is not of type 'int'!" % (name)
-                raise_error(err_msg, TypeError, logger)
+                e13.raise_error(err_msg, TypeError, logger)
 
         # Check for negative value
         elif 'neg' in args:
@@ -357,7 +358,7 @@ def check_vals(values, name, *args):
             else:
                 err_msg = ("Input argument '%s%s' is not negative!"
                            % (name, index if values.ndim != 0 else ''))
-                raise_error(err_msg, ValueError, logger)
+                e13.raise_error(err_msg, ValueError, logger)
 
         # Check for non-negative value
         elif 'nneg' in args:
@@ -370,7 +371,7 @@ def check_vals(values, name, *args):
             else:
                 err_msg = ("Input argument '%s%s' is not non-negative!"
                            % (name, index if values.ndim != 0 else ''))
-                raise_error(err_msg, ValueError, logger)
+                e13.raise_error(err_msg, ValueError, logger)
 
         # Check for normalized value [-1, 1]
         elif 'normal' in args:
@@ -383,7 +384,7 @@ def check_vals(values, name, *args):
             else:
                 err_msg = ("Input argument '%s%s' is not normalized!"
                            % (name, index if values.ndim != 0 else ''))
-                raise_error(err_msg, ValueError, logger)
+                e13.raise_error(err_msg, ValueError, logger)
 
         # Check for non-positive value
         elif 'npos' in args:
@@ -396,7 +397,7 @@ def check_vals(values, name, *args):
             else:
                 err_msg = ("Input argument '%s%s' is not non-positive!"
                            % (name, index if values.ndim != 0 else ''))
-                raise_error(err_msg, ValueError, logger)
+                e13.raise_error(err_msg, ValueError, logger)
 
         # Check for non-zero value
         elif 'nzero' in args:
@@ -409,7 +410,7 @@ def check_vals(values, name, *args):
             else:
                 err_msg = ("Input argument '%s%s' is not non-zero!"
                            % (name, index if values.ndim != 0 else ''))
-                raise_error(err_msg, ValueError, logger)
+                e13.raise_error(err_msg, ValueError, logger)
 
         # Check for positive value
         elif 'pos' in args:
@@ -422,13 +423,13 @@ def check_vals(values, name, *args):
             else:
                 err_msg = ("Input argument '%s%s' is not positive!"
                            % (name, index if values.ndim != 0 else ''))
-                raise_error(err_msg, ValueError, logger)
+                e13.raise_error(err_msg, ValueError, logger)
 
         # If none of the criteria is found, the criteria are invalid
         else:
             err_msg = ("Input argument 'args' contains invalid elements (%s)!"
                        % (args))
-            raise_error(err_msg, ValueError, logger)
+            e13.raise_error(err_msg, ValueError, logger)
 
     # If no criteria are left, it must be a finite value
     else:
@@ -440,11 +441,11 @@ def check_vals(values, name, *args):
         except TypeError:
             err_msg = ("Input argument '%s%s' is not of type 'int' or 'float'!"
                        % (name, index if values.ndim != 0 else ''))
-            raise_error(err_msg, TypeError, logger)
+            e13.raise_error(err_msg, TypeError, logger)
         else:
             err_msg = ("Input argument '%s%s' is not finite!"
                        % (name, index if values.ndim != 0 else ''))
-            raise_error(err_msg, ValueError, logger)
+            e13.raise_error(err_msg, ValueError, logger)
 
     # Convert values back to its original type
     if(arr_type == 'tuple'):
@@ -458,6 +459,152 @@ def check_vals(values, name, *args):
     return(values)
 
 
+# Define class factory that returns a specialized h5py.File class
+def get_PRISM_File(prism_hdf5_file):
+    """
+    Returns a class definition ``PRISM_File(mode, emul_s=None, **kwargs)``.
+
+    This class definition is a specialized version of the :class:`~h5py.File`
+    class with the filename automatically set to `prism_hdf5_file` and added
+    logging to the constructor and destructor methods.
+
+    Parameters
+    ----------
+    prism_hdf5_file : str
+        Absolute path to the master HDF5-file that is used in a
+        :obj:`~prism.Pipeline` instance.
+
+    Returns
+    -------
+    PRISM_File : class
+        Definition of the class ``PRISM_File(mode, emul_s=None, **kwargs)``.
+
+    """
+
+    # Split provided prism_hdf5_file up into parts
+    parts = path.splitext(prism_hdf5_file)
+
+    # Override h5py's File.__init__() and __exit__() methods
+    class PRISM_File(h5py.File):
+        """
+        Custom :class:`~h5py.File` class that automatically knows where all
+        *PRISM* HDF5-files are located when created by the
+        :func:`~get_PRISM_File` class factory. Additionally, certain keyword
+        arguments have default values and the opening/closing of an HDF5-file
+        is logged.
+
+        """
+
+        # Override __init__() to include default settings and logging
+        def __init__(self, mode, emul_s=None, **kwargs):
+            """
+            Opens the master HDF5-file `prism_hdf5_file` in `mode` according to
+            some set of default parameters.
+
+            Parameters
+            ----------
+            mode : {'r'; 'r+'; 'w'; 'w-'/'x'; 'a'}
+                String indicating how the HDF5-file needs to be opened.
+
+            Optional
+            --------
+            emul_s : int or None. Default: None
+                If int, number indicating the requested emulator system file to
+                open.
+                If *None*, the master HDF5-file itself is opened.
+            kwargs : dict. Default: ``{'driver': None, 'libver': 'earliest'}``
+                Other keyword arguments that need to be given to the
+                :func:`~h5py.File` function.
+
+            """
+
+            # Save emul_s as a property
+            self.emul_s = emul_s
+
+            # Set default settings
+            hdf5_kwargs = {'driver': None,
+                           'libver': 'earliest'}
+
+            # Check emul_s and obtain proper logger
+            if self.emul_s is None:
+                # Only controller opens master file for writing, so use CLogger
+                sub_str = ''
+                logger = getCLogger('M-HDF5')
+            else:
+                sub_str = '_%i' % (self.emul_s)
+                logger = getRLogger('S-HDF5')
+
+            # Add sub_str to filename
+            filename = ''.join([parts[0], sub_str, parts[1]])
+
+            # Update hdf5_kwargs with provided ones
+            hdf5_kwargs.update(kwargs)
+
+            # Log that an HDF5-file is being opened
+            if self.emul_s is None:
+                logger.info("Opening master HDF5-file (mode: %r)." % (mode))
+            else:
+                logger.info("Opening system HDF5-file %i (mode: %r)."
+                            % (self.emul_s, mode))
+
+            # Inheriting File __init__()
+            super().__init__(filename, mode, **hdf5_kwargs)
+
+        # Override __exit__() to include logging
+        def __exit__(self, *args):
+            # Log that an HDF5-file will be closed
+            if self.emul_s is None:
+                logger = getCLogger('M-HDF5')
+                logger.info("Closing master HDF5-file.")
+            else:
+                logger = getRLogger('S-HDF5')
+                logger.info("Closing system HDF5-file %i." % (self.emul_s))
+
+            # Inheriting File __exit__()
+            super().__exit__(*args)
+
+    # Return PRISM_File class definition
+    return(PRISM_File)
+
+
+# Define function that prints a string with the BibTeX entry to PRISM's paper
+def get_bibtex():
+    """
+    Prints a string that gives the BibTeX entry for citing the *PRISM* paper
+    (Van der Velden et al. 2019, ApJS, 242, 22).
+
+    """
+
+    # Create string with BibTeX entry
+    bibtex = dedent(
+        r"""
+        @ARTICLE{2019ApJS..242...22V,
+            author = {{van der Velden}, E. and {Duffy}, A.~R. and {Croton}, D.
+                and {Mutch}, S.~J. and {Sinha}, M.},
+            title = "{Model dispersion with PRISM; an alternative to MCMC for
+                rapid analysis of models}",
+            journal = {\apjs},
+            keywords = {Astrophysics - Instrumentation and Methods for
+                Astrophysics, Physics - Computational Physics},
+            year = "2019",
+            month = "Jun",
+            volume = {242},
+            number = {2},
+            eid = {22},
+            pages = {22},
+            doi = {10.3847/1538-4365/ab1f7d},
+            archivePrefix = {arXiv},
+            eprint = {1901.08725},
+            primaryClass = {astro-ph.IM},
+            adsurl = {https://ui.adsabs.harvard.edu/abs/2019ApJS..242...22V},
+            adsnote = {Provided by the SAO/NASA Astrophysics Data System}
+        }
+        """)
+
+    # Print the string
+    print(bibtex.strip())
+
+
 # This function returns a logging.Formatter used for PRISM logging
 def get_formatter():
     """
@@ -502,7 +649,7 @@ def get_handler(filename):
 def get_info():
     """
     Prints a string that gives an overview of all information relevant to the
-    PRISM package distribution.
+    *PRISM* package distribution.
 
     """
 
@@ -550,112 +697,6 @@ def get_info():
     print(info_str.strip())
 
 
-# Define class factory that returns a specialized h5py.File class
-def get_PRISM_File(prism_hdf5_file):
-    """
-    Returns a class definition ``PRISM_File(mode, emul_s=None, **kwargs)``.
-
-    This class definition is a specialized version of the :class:`~h5py.File`
-    class with the filename automatically set to `prism_hdf5_file` and added
-    logging to the constructor and destructor methods.
-
-    Parameters
-    ----------
-    prism_hdf5_file : str
-        Absolute path to the master HDF5-file that is used in a
-        :obj:`~prism.Pipeline` instance.
-
-    Returns
-    -------
-    PRISM_File : class
-        Definition of the class ``PRISM_File(mode, emul_s=None, **kwargs)``.
-
-    """
-
-    # Override h5py's File.__init__() and __exit__() methods
-    class PRISM_File(h5py.File):
-        """
-        Custom :class:`~h5py.File` class that automatically knows where all
-        *PRISM* HDF5-files are located when created by the
-        :func:`~get_PRISM_File` class factory. Additionally, certain keyword
-        arguments have default values and the opening/closing of an HDF5-file
-        is logged.
-
-        """
-
-        # Override __init__() to include default settings and logging
-        def __init__(self, mode, emul_s=None, **kwargs):
-            """
-            Opens the master HDF5-file `prism_hdf5_file` in `mode` according to
-            some set of default parameters.
-
-            Parameters
-            ----------
-            mode : {'r', 'r+', 'w', 'w-'/'x', 'a'}
-                String indicating how the HDF5-file needs to be opened.
-
-            Optional
-            --------
-            emul_s : int or None. Default: None
-                If int, number indicating the requested emulator system file to
-                open.
-                If *None*, the master HDF5-file itself is opened.
-            kwargs : dict. Default: ``{'driver': None, 'libver': 'earliest'}``
-                Other keyword arguments that need to be given to the
-                :func:`~h5py.File` function.
-
-            """
-
-            # Save emul_s as a property
-            self.emul_s = emul_s
-
-            # Set default settings
-            hdf5_kwargs = {'driver': None,
-                           'libver': 'earliest'}
-
-            # Check emul_s and obtain proper logger
-            if self.emul_s is None:
-                # Only controller opens master file for writing, so use CLogger
-                sub_str = ''
-                logger = getCLogger('M-HDF5')
-            else:
-                sub_str = '_%i' % (self.emul_s)
-                logger = getRLogger('S-HDF5')
-
-            # Add sub_str to filename
-            parts = path.splitext(prism_hdf5_file)
-            filename = ''.join([parts[0], sub_str, parts[1]])
-
-            # Update hdf5_kwargs with provided ones
-            hdf5_kwargs.update(kwargs)
-
-            # Log that an HDF5-file is being opened
-            if self.emul_s is None:
-                logger.info("Opening master HDF5-file (mode: %r)." % (mode))
-            else:
-                logger.info("Opening system HDF5-file %i (mode: %r)."
-                            % (self.emul_s, mode))
-
-            # Inheriting File __init__()
-            super().__init__(filename, mode, **hdf5_kwargs)
-
-        # Override __exit__() to include logging
-        def __exit__(self, *args):
-            # Log that an HDF5-file will be closed
-            if self.emul_s is None:
-                logger = getCLogger('M-HDF5')
-                logger.info("Closing master HDF5-file.")
-            else:
-                logger = getRLogger('S-HDF5')
-                logger.info("Closing system HDF5-file %i." % (self.emul_s))
-
-            # Inheriting File __exit__()
-            super().__exit__(*args)
-
-    # Return PRISM_File class definition
-    return(PRISM_File)
-
-
 # Define custom getLogger function that adds the CFilter
 def getCLogger(name=None):
     """
