@@ -5,8 +5,7 @@
 from os import path
 
 # Package imports
-from e13tools.core import InputError
-from e13tools.sampling import lhd
+import e13tools as e13
 from emcee import EnsembleSampler
 import numpy as np
 from py.path import local
@@ -19,9 +18,6 @@ from prism._pipeline import Pipeline
 from prism.modellink.tests.modellink import GaussianLink2D
 from prism.utils.mcmc import get_hybrid_lnpost_fn, get_walkers
 
-# Save the path to this directory
-dirpath = path.dirname(__file__)
-
 # Set the random seed of NumPy
 np.random.seed(0)
 
@@ -29,6 +25,10 @@ np.random.seed(0)
 local.get_temproot().chdir()
 
 
+# %% GLOBALS
+DIR_PATH = path.dirname(__file__)           # Path to directory of this file
+
+
 # %% CUSTOM FUNCTIONS
 # Create Pipeline object to use for testing purposes
 @pytest.fixture(scope='module')
@@ -36,7 +36,7 @@ def pipe(tmpdir_factory):
     tmpdir = tmpdir_factory.mktemp('test_mcmc')
     root_dir = path.dirname(tmpdir.strpath)
     working_dir = path.basename(tmpdir.strpath)
-    prism_file = path.join(dirpath, 'data/prism_default.txt')
+    prism_file = path.join(DIR_PATH, 'data/prism_default.txt')
     modellink_obj = GaussianLink2D()
     np.random.seed(0)
     pipeline_obj = Pipeline(modellink_obj, root_dir=root_dir,
@@ -50,7 +50,7 @@ def lnpost(par_set, pipe):
     # Obtain mod_out
     emul_i = pipe._emulator._emul_i
     if not isinstance(par_set, dict):
-        par_dict = sdict(zip(pipe._modellink._par_name, par_set))
+        par_dict = pipe._modellink._get_sam_dict(par_set)
     else:
         par_dict = par_set
     mod_out = pipe._modellink.call_model(emul_i, par_dict,
@@ -81,7 +81,7 @@ class Test_get_hybrid_lnpost_fn(object):
 
     # Try to provide a non-callable function
     def test_non_callable(self, pipe):
-        with pytest.raises(InputError):
+        with pytest.raises(e13.InputError):
             get_hybrid_lnpost_fn(np.array(1), pipe)
 
     # Try to provide a non-Pipeline object
@@ -92,7 +92,7 @@ class Test_get_hybrid_lnpost_fn(object):
     # Try to provide a Pipeline object that uses a non-default emulator
     def test_invalid_emulator(self, pipe):
         pipe._emulator._emul_type = 'test'
-        with pytest.raises(InputError):
+        with pytest.raises(e13.InputError):
             get_hybrid_lnpost_fn(lnpost, pipe)
         pipe._emulator._emul_type = 'default'
 
@@ -112,8 +112,8 @@ class Test_get_hybrid_lnpost_fn(object):
         hybrid_lnpost = get_hybrid_lnpost_fn(lnpost, pipe, par_dict=True,
                                              unit_space=True, impl_prior=False)
         assert hybrid_lnpost({'A': 0.5, 'B': 0.5}, pipe) == -np.infty
-        hybrid_lnpost(sdict(zip(pipe._modellink._par_name,
-                                pipe._modellink._par_est)), pipe)
+        hybrid_lnpost(pipe._modellink._get_sam_dict(pipe._modellink._par_est),
+                      pipe)
 
 
 # Pytest for get_walkers
@@ -123,6 +123,7 @@ class Test_get_walkers(object):
         if(pipe._size == 1):
             with pytest.raises(RequestError):
                 get_walkers(pipe)
+            get_walkers(pipe, init_walkers=10)
         pipe.analyze()
         get_walkers(pipe)
         pipe.construct()
@@ -136,26 +137,27 @@ class Test_get_walkers(object):
     # Try to provide a Pipeline object that uses a non-default emulator
     def test_invalid_emulator(self, pipe):
         pipe._emulator._emul_type = 'test'
-        with pytest.raises(InputError):
+        with pytest.raises(e13.InputError):
             get_walkers(pipe)
         pipe._emulator._emul_type = 'default'
 
     # Try to provide a non-callable function
     def test_non_callable(self, pipe):
-        with pytest.raises(InputError):
+        with pytest.raises(e13.InputError):
             get_walkers(pipe, lnpost_fn=np.array(1))
 
     # Try to provide a custom set of init_walkers
     def test_init_walkers_set(self, pipe):
-        get_walkers(pipe, init_walkers=lhd(10, pipe._modellink._n_par, None,
-                                           'center', pipe._criterion, 100),
+        get_walkers(pipe,
+                    init_walkers=e13.lhd(10, pipe._modellink._n_par, None,
+                                         'center', pipe._criterion, 100),
                     unit_space=True)
 
     # Try to provide a custom dict of init_walkers
     def test_init_walkers_dict(self, pipe):
-        sam_set = lhd(10, pipe._modellink._n_par, pipe._modellink._par_rng,
-                      'center', pipe._criterion, 100)
-        sam_dict = sdict(zip(pipe._modellink._par_name, sam_set.T))
+        sam_set = e13.lhd(10, pipe._modellink._n_par, pipe._modellink._par_rng,
+                          'center', pipe._criterion, 100)
+        sam_dict = pipe._modellink._get_sam_dict(sam_set)
         p0_walkers = get_walkers(pipe, init_walkers=sam_dict)[1]
         if pipe._is_controller:
             assert isinstance(p0_walkers, dict)
@@ -164,12 +166,21 @@ class Test_get_walkers(object):
     def test_init_walkers_size(self, pipe):
         get_walkers(pipe, init_walkers=10)
 
+    # Try to request a specific number of walkers
+    def test_req_n_walkers(self, pipe):
+        if pipe._is_controller:
+            req_n_walkers = pipe._comm.bcast(pipe._n_impl_sam[-1]+1, 0)
+        else:
+            req_n_walkers = pipe._comm.bcast(None, 0)
+        get_walkers(pipe, req_n_walkers=req_n_walkers)
+
     # Try to provide a set of implausible init_walkers
     def test_no_plausible_init_walkers(self, pipe):
-        with pytest.raises(InputError):
-            get_walkers(pipe, init_walkers=lhd(1, pipe._modellink._n_par,
-                                               pipe._modellink._par_rng,
-                                               'center', pipe._criterion, 100))
+        with pytest.raises(e13.InputError):
+            get_walkers(pipe,
+                        init_walkers=e13.lhd(1, pipe._modellink._n_par,
+                                             pipe._modellink._par_rng,
+                                             'center', pipe._criterion, 100))
 
     # Try to provide a custom lnpost function
     def test_custom_lnpost(self, pipe):
